@@ -1,5 +1,6 @@
 form_action_types = {}
 
+from __future__ import nested_scopes
 import os, string
 from AccessControl import ClassSecurityInfo
 import Globals
@@ -28,13 +29,14 @@ class FormController(UniqueObject, SimpleItemWithProperties):
     security = ClassSecurityInfo()
 
     id = 'portal_form_controller'
-    title = 'Manage form validation and post-validation actions'
+    title = 'Manages form validation and post-validation actions'
     meta_type= 'Form Controller Tool'
 
     manage_options = ( ({'label':'Overview', 'action':'manage_overview'},
                         {'label':'Documentation', 'action':'manage_docs'},
                         {'label': 'Validation', 'action': 'manage_formValidatorsForm'},
-                        {'label': 'Actions', 'action': 'manage_formActionsForm'},) +
+                        {'label': 'Actions', 'action': 'manage_formActionsForm'},
+                        {'label': 'Purge', 'action': 'manage_purgeForm'},) +
                        SimpleItemWithProperties.manage_options)
 
     security.declareProtected(ManagePortal, 'manage_overview')
@@ -54,6 +56,10 @@ class FormController(UniqueObject, SimpleItemWithProperties):
     manage_formValidatorsForm = PageTemplateFile(os.path.join('www','manage_formValidatorsForm'), globals())
     manage_formValidatorsForm.__name__ = 'manage_formValidatorsForm'
 
+    security.declareProtected(ManagePortal, 'manage_purgeForm')
+    manage_purgeForm = PageTemplateFile(os.path.join('www','manage_purgeForm'), globals())
+    manage_purgeForm.__name__ = 'manage_purgeForm'
+
     # some aliases
     security.declareProtected(ManagePortal, 'manage_main')
     manage_main = manage_overview
@@ -79,13 +85,6 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         return self._docs
 
 
-    security.declarePrivate('manage_afterAdd')
-    def manage_afterAdd(self, object, container):
-        portal = getToolByName(object, 'portal_url').getPortalObject()
-        object.plone = portal.__class__.__name__ == 'PloneSite'
-        SimpleItemWithProperties.manage_afterAdd(self, object, container)
-
-
     def view(self, REQUEST, RESPONSE):
         """Invokes the default view."""
         return self.__call__(REQUEST, RESPONSE)
@@ -105,7 +104,8 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         s = bad_id(id)
         if s:
             return '\'%s\' is not a valid id' % (id)
-        if self.plone:
+        # extra checks for Plone sites
+        if portal.__class__.__name__ == 'PloneSite':
             if hasattr(portal, 'portal_properties') and \
                 hasattr(portal.portal_properties, 'site_properties') and \
                 hasattr(portal.portal_properties.site_properties, 'invalid_ids'):
@@ -282,7 +282,7 @@ class FormController(UniqueObject, SimpleItemWithProperties):
                 container.delete(FormActionKey(old_object_id, old_status, old_context_type, old_button, self))
 
 
-    def getValidators(self, object_id, context_type, button):
+    def getValidators(self, id, context_type, button):
         return self.validators.match(id, context_type, button)
 
 
@@ -407,4 +407,45 @@ class FormController(UniqueObject, SimpleItemWithProperties):
         return type_name
 
 
+    security.declareProtected(ManagePortal, 'purge')
+    def purge(self):
+        """Remove actions and validators for ids that no longer correspond to
+        objects in the portal"""
+        actions = self.actions.getFiltered()
+        action_dict = {}
+        for a in actions:
+            action_dict[a.getObjectId()] = 1
+        validators = self.validators.getFiltered()
+        validator_dict = {}
+        for v in validators:
+            validator_dict[v.getObjectId()] = 1
+
+        def fn(obj, dict):
+            dict[obj.getId()] = 0
+            print str(dict)
+        meta_types = ['Controller Page Template', 'Controller Page Template (File)', 'Filesystem Controller Page Template', 'Controller Python Script', 'Filesystem Controller Python Script']
+        portal = getToolByName(self, 'portal_url').getPortalObject()
+        catalog = getToolByName(self, 'portal_catalog')
+        result = catalog.ZopeFindAndApply(portal, obj_metatypes=meta_types, search_sub=1, result=[])
+        for (path, r) in result:
+            if action_dict.has_key(r.getId()):
+                del action_dict[r.getId()]
+            if validator_dict.has_key(r.getId()):
+                del validator_dict[r.getId()]
+
+        n_actions = 0
+        for k in action_dict.keys():
+            to_be_deleted = self.actions.getFiltered(object_id=k)
+            n_actions += len(to_be_deleted)
+            for a in to_be_deleted:
+                self.actions.delete(a.getKey())
+        catalog.ZopeFindAndApply(portal, meta_types, search_sub=1, apply_func=lambda o: fn(o, validator_dict))
+        n_validators = 0
+        for k in validator_dict.keys():
+            to_be_deleted = self.validators.getFiltered(object_id=k)
+            n_validators += len(to_be_deleted)
+            for v in to_be_deleted:
+                self.validators.delete(v.getKey())
+        return '%d action overrides deleted, %d validator overrides deleted' % (n_actions, n_validators)
+
 Globals.InitializeClass(FormController)
