@@ -1,10 +1,8 @@
 import re
 import sys
 import traceback
-from types import TupleType, UnicodeType, DictType, StringType
-from urllib import urlencode
+from types import TupleType, UnicodeType, StringType
 import urlparse
-from cgi import parse_qs
 
 from zLOG import LOG, INFO, WARNING
 
@@ -13,19 +11,17 @@ from Products.CMFCore.utils import UniqueObject, getToolByName
 from Products.CMFCore.utils import _checkPermission, \
      _getAuthenticatedUser, limitGrantedRoles
 from Products.CMFCore.utils import getToolByName, _dtmldir
-from Products.CMFCore.ActionInformation import ActionInformation
 from Products.CMFCore import CMFCorePermissions
 from Products.CMFCore.interfaces.DublinCore import DublinCore, MutableDublinCore
 from Products.CMFCore.interfaces.Discussions import Discussable
 from Products.CMFCore.WorkflowCore import WorkflowException
-from Products.CMFPlone import ToolNames
+from Products.CMFPlone import ToolNames, transaction_note
 
 from OFS.SimpleItem import SimpleItem
 from OFS.ObjectManager import bad_id
-from Globals import InitializeClass, DTMLFile
-from AccessControl import ClassSecurityInfo, Unauthorized
-from StatelessTree import constructNavigationTreeViewBuilder, \
-     NavigationTreeViewBuilder as NTVB
+from Globals import InitializeClass
+from AccessControl import ClassSecurityInfo
+from StatelessTree import NavigationTreeViewBuilder as NTVB
 from ZODB.POSException import ConflictError
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
 
@@ -41,7 +37,7 @@ except:
 def log(summary='', text='', log_level=INFO):
     LOG('Plone Debug', log_level, summary, text)
 
-EMAIL_RE = re.compile(r"^([0-9a-zA-Z_&.+-]+!)*[0-9a-zA-Z_&.+-]+@(([0-9a-z]([0-9a-z-]*[0-9a-z])?\.)+[a-z]{2,6}|([0-9]{1,3}\.){3}[0-9]{1,3})$")
+EMAIL_RE = re.compile(r"^(\w&.+-]+!)*[\w&.+-]+@(([0-9a-z]([0-9a-z-]*[0-9a-z])?\.)+[a-z]{2,6}|([0-9]{1,3}\.){3}[0-9]{1,3})$", re.IGNORECASE)
 EMAIL_CUTOFF_RE = re.compile(r".*[\n\r][\n\r]") # used to find double new line (in any variant)
 
 #XXX Remove this when we don't depend on python2.1 any longer, use email.Utils.getaddresses instead
@@ -86,7 +82,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         if not self.validateSingleEmailAddress(mfrom):
             raise ValueError, 'The "from" email address did not validate'
         
-        if not self.validateEmailAddresses(to):
+        if not self.validateEmailAddresses(mto):
             raise ValueError, 'The "to" email address did not validate'
         
         host = self.MailHost
@@ -183,43 +179,41 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                      , language=None
                      , rights=None
                      ,  **kwargs):
-        """ responsible for setting metadata on a content object
-            we assume the obj implemented IDublinCoreMetadata
+        """ Responsible for setting metadata on a content object
+            we assume the obj implements IDublinCoreMetadata.
         """
         mt = getToolByName(self, 'portal_membership')
         if not mt.checkPermission(CMFCorePermissions.ModifyPortalContent, obj):
-            raise 'Unauthorized' #Hooray!  You can not import Unauthorized in TTW Scripts
+            raise 'Unauthorized'    # FIXME: Some scripts rely on this being string?
 
-        REQUEST=self.REQUEST
-        pfx=self.field_prefix
+        REQUEST = self.REQUEST
+        pfx = self.field_prefix
 
-        def tuplify( value ):
-            if not type(value) is TupleType:
-                value = tuple( value )
-            temp = filter( None, value )
-            return tuple( temp )
+        def getfield(request, name, default=None, pfx=pfx):
+            return request.form.get(pfx+name, default)
+
+        def tuplify(value):
+            return tuple(filter(None, value))
 
         if DublinCore.isImplementedBy(obj):
             if title is None:
-                title=REQUEST.get(pfx+'title', obj.Title())
-            if subject is None:
-                subject=REQUEST.get(pfx+'subject', obj.Subject())
+                title = getfield(REQUEST, 'title')
             if description is None:
-                description=REQUEST.get(pfx+'description', obj.Description())
+                description = getfield(REQUEST, 'description')
+            if subject is None:
+                subject = getfield(REQUEST, 'subject')
+            if subject is not None:
+                subject = tuplify(subject)
             if contributors is None:
-                contributors=tuplify(REQUEST.get(pfx+'contributors',
-                                                 obj.Contributors()))
-            else:
-                contributors=tuplify(contributors)
-
+                contributors = getfield(REQUEST, 'contributors')
+            if contributors is not None:
+                contributors = tuplify(contributors)
             if effective_date is None:
-                effective_date=REQUEST.get(pfx+'effective_date',
-                                           obj.EffectiveDate())
+                effective_date = getfield(REQUEST, 'effective_date')
             if effective_date == '':
                 effective_date = 'None'
             if expiration_date is None:
-                expiration_date=REQUEST.get(pfx+'expiration_date',
-                                            obj.ExpirationDate())
+                expiration_date = getfield(REQUEST, 'expiration_date')
             if expiration_date == '':
                 expiration_date = 'None'
 
@@ -242,16 +236,25 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
             disc_tool.overrideDiscussionFor(obj, allowDiscussion)
 
         if MutableDublinCore.isImplementedBy(obj):
-            if title: obj.setTitle(title)
-            if description: obj.setDescription(description)
-            if subject: obj.setSubject(subject)
-            if effective_date: obj.setEffectiveDate(effective_date)
-            if expiration_date: obj.setExpirationDate(expiration_date)
-            if contributors: obj.setContributors(contributors)
-            if format: obj.setFormat(format)
-            if language: obj.setLanguage(language)
-            if rights: obj.setRights(rights)
-            # make the catalog aware of changes.
+            if title is not None: 
+                obj.setTitle(title)
+            if description is not None: 
+                obj.setDescription(description)
+            if subject is not None: 
+                obj.setSubject(subject)
+            if contributors is not None: 
+                obj.setContributors(contributors)
+            if effective_date is not None: 
+                obj.setEffectiveDate(effective_date)
+            if expiration_date is not None: 
+                obj.setExpirationDate(expiration_date)
+            if format is not None: 
+                obj.setFormat(format)
+            if language is not None: 
+                obj.setLanguage(language)
+            if rights is not None: 
+                obj.setRights(rights)
+            # Make the catalog aware of changes
             obj.reindexObject()
 
     def _renameObject(self, obj, id):
@@ -274,7 +277,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
             # that Latin-1 is probably not enough.
             msg = msg.encode('utf-8')
         if not get_transaction().description:
-            get_transaction().note(msg)
+            transaction_note(msg)
 
     security.declarePublic('contentEdit')
     def contentEdit(self, obj, **kwargs):
@@ -527,7 +530,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
     security.declarePublic('getInheritedLocalRoles')
     def getInheritedLocalRoles(self, here):
         portal = here.portal_url.getPortalObject()
-        result=()
+        result=[]
         cont=1
         if portal != here:
             parent = here.aq_parent
@@ -546,13 +549,13 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                             break
                     if found==0:
                         # add it to result
-                        result=result + ((user, roles, type, name),)
+                        result.append((user, roles, type, name))
                 if parent==portal:
                     cont=0
                 else:
                     parent=parent.aq_parent
 
-        return result
+        return tuple(result)
 
     security.declarePublic('browserDefault')
     def browserDefault(self, obj):
