@@ -5,6 +5,7 @@
 // in the plone_javascript_variables.js file. Any other variables from Plone
 // that you want to pass into these scripts should be placed there.
 
+/* <dtml-var "enableHTTPCompression(request=REQUEST, debug=1, js=1)"> (this is for http compression) */
 
 function registerPloneFunction(func){
     // registers a function to fire onload. 
@@ -15,6 +16,12 @@ function registerPloneFunction(func){
     else if (window.attachEvent) window.attachEvent("onload",func);   
   }
 
+function unRegisterPloneFunction(func){
+    // uregisters a previous function to fire onload. 
+    if (window.removeEventListener) window.removeEventListener("load",func,false);
+    else if (window.detachEvent) window.detachEvent("onload",func);   
+  }
+
 function getContentArea(){
 	// to end all doubt on where the content sits. It also felt a bit silly doing this over and over in every
 	// function, even if it is a tiny operation. Just guarding against someone changing the names again, in the name
@@ -392,7 +399,8 @@ function scanforlinks(){
                      if (linkval.indexOf(protocols[p]+':') == 0){
                     // this link matches the protocol . add a classname protocol+link
                     //links[i].className = 'link-'+protocols[p]
-                    wrapNode(links[i], 'span', 'link-'+protocols[p])
+                        wrapNode(links[i], 'span', 'link-'+protocols[p])
+                        break;
                     }
                 }
             }else{
@@ -477,7 +485,7 @@ function highlightSearchTerm() {
         query = window.location.search
         // _robert_ ie 5 does not have decodeURI 
         if (typeof decodeURI != 'undefined'){
-            query = decodeURI(unescape(query)) // thanks, Casper 
+            query = unescape(decodeURI(query)) // thanks, Casper 
         }
         else {
             return false
@@ -500,7 +508,12 @@ function highlightSearchTerm() {
                 // make sure we start the right place and not higlight menuitems or breadcrumb
                 contentarea = getContentArea();
 				for (q=0;q<queries.length;q++) {
-                    climb(contentarea,queries[q]);
+                                       // don't highlight reserved catalog search terms
+                                       if (queries[q].toLowerCase() != 'not'
+                                               && queries[q].toLowerCase() != 'and'
+                                               && queries[q].toLowerCase() != 'or') {
+                       climb(contentarea,queries[q]);
+                                       }
                 }
             }
         }
@@ -588,21 +601,6 @@ function onJsCalendarDateUpdate(cal) {
     // minute.value= cal.params.inputField.value.substring(14,16);
 }
 
-// this funtion updates a hidden date filed with the current values of the widgets
-function update_date_field(field,year,month,day,hour,minute) {
-    var field  = document.getElementById(field);
-    var date   = document.getElementById(date);
-    var year   = document.getElementById(year);
-    var month  = document.getElementById(month);
-    var day    = document.getElementById(day);
-    var hour   = document.getElementById(hour);
-    var minute = document.getElementById(minute);
-    if (year.value > 0) {
-	field.value = year.value + "-" + month.value + "-" + day.value + " " + hour.options[hour.selectedIndex].value + ":" + minute.options[minute.selectedIndex].value;
-    } else {
-	field.value = '';
-    }
-}
 
 function showJsCalendar(input_id_anchor, input_id, input_id_year, input_id_month, input_id_day, input_id_hour, input_id_minute, yearStart, yearEnd) {
     // do what jscalendar-x.y.z/calendar-setup.js:Calendar.setup would do
@@ -677,9 +675,55 @@ function showJsCalendar(input_id_anchor, input_id, input_id_year, input_id_month
 }
 
 
+// This function updates a hidden date field with the current values of the widgets
+function update_date_field(field, year, month, day, hour, minute, ampm)
+{
+    var field  = document.getElementById(field)
+    var date   = document.getElementById(date)
+    var year   = document.getElementById(year)
+    var month  = document.getElementById(month)
+    var day    = document.getElementById(day)
+    var hour   = document.getElementById(hour)
+    var minute = document.getElementById(minute)
+    var ampm   = document.getElementById(ampm)
+
+    if (0 < year.value)
+    {
+        // Return ISO date string
+        // Note: This relies heavily on what date_components_support.py puts into the form.
+        field.value = year.value + "-" + month.value + "-" + day.value + " " + hour.value + ":" + minute.value
+        // Handle optional AM/PM
+        if (ampm && ampm.value)
+            field.value = field.value + " " + ampm.value
+    } 
+    else 
+    {
+        // Return empty string
+        field.value = ''
+        // Reset widgets
+        month.options[0].selected = 1
+        day.options[0].selected = 1
+        hour.options[0].selected = 1
+        minute.options[0].selected = 1
+        if (ampm && ampm.options)
+            ampm.options[0].selected = 1
+    }
+}
 
 
 
+function fullscreenMode() {
+    if (document.getElementById('portal-top').style.display == 'none') {
+        document.getElementById('portal-top').style.display = 'block';
+        document.getElementById('portal-column-one').style.display = 'block';
+        document.getElementById('portal-column-two').style.display = 'block';
+        }
+    else {
+        document.getElementById('portal-top').style.display = 'none';
+        document.getElementById('portal-column-one').style.display = 'none';
+        document.getElementById('portal-column-two').style.display = 'none';
+    }
+}
 
 
 // and finally : Mike Malloch's fixes for Internet Explorer 5 - 
