@@ -1,44 +1,19 @@
 ## Script (Python) "aboveInThread"
-
 ##bind container=container
-
 ##bind context=context
-
 ##bind namespace=
-
 ##bind script=script
-
 ##bind subpath=traverse_subpath
-
 ##parameters=
-
 ##title=Discussion parent breadcrumbs
-
-
-
 breadcrumbs = ''
-
+crumbs = []
 parents = context.parentsInThread()
 
-
-
 if parents:
-
-    breadcrumbs = ''
-
     for parent in parents:
+        crumbs.append('<a href="%s">%s</a> ' % (parent.absolute_url(), parent.Title()))
 
-        p_str = '<a href="%s">%s</a> <strong>&raquo;</strong> ' % (parent.absolute_url(), parent.Title())
-
-        breadcrumbs = breadcrumbs + p_str
-
-
-
-    breadcrumbs = breadcrumbs[:-1] + '<p>'
-
-        
+    breadcrumbs = '<strong>&raquo;</strong> '.join(crumbs)
 
 return breadcrumbs
-
-
-
