@@ -132,11 +132,81 @@ class TestCheckIdAvailable(PloneTestCase.PloneTestCase):
         self.failIf(self.lpf.checkIdAvailable('foo'))
 
 
+class TestFolderListing(PloneTestCase.PloneTestCase):
+    # Tests for http://plone.org/collector/3512
+
+    def afterSetUp(self):
+        self.workflow = self.portal.portal_workflow
+        # Get rid of the .personal subfolder
+        membership = self.portal.portal_membership
+        self.folder._delObject(membership.personal_id)
+        # Create some objects to list
+        self.folder.invokeFactory('Folder', id='sub1')
+        self.folder.invokeFactory('Folder', id='sub2')
+        self.folder.invokeFactory('Document', id='doc1')
+        self.folder.invokeFactory('Document', id='doc2')
+
+    def _contentIds(self, folder):
+        return [ob.getId() for ob in folder.listFolderContents()]
+
+    def testListFolderContentsOmitsPrivateObjects(self):
+        self.workflow.doActionFor(self.folder.doc1, 'hide')
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder),
+                         ['sub1', 'sub2', 'doc2'])
+
+    def testListFolderContentsOmitsPrivateFolders(self):
+        self.workflow.doActionFor(self.folder.sub1, 'hide')
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder),
+                         ['sub2', 'doc1', 'doc2'])
+
+    def testBugReport(self):
+        # Perform the steps-to-reproduce in the collector issue:
+
+        # 2)
+        self.folder.invokeFactory('Folder', id='A')
+        self.workflow.doActionFor(self.folder.A, 'publish')
+
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder.A), [])
+
+        # 3)
+        self.login()
+        self.folder.A.invokeFactory('Document', id='B')
+        self.folder.A.B.manage_permission('View', ['Manager', 'Reviewer'], acquire=0)
+
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder.A), [])
+
+        # 4)
+        self.login()
+        self.folder.A.invokeFactory('Folder', id='C')
+        self.folder.A.C.manage_permission('View', ['Manager', 'Reviewer'], acquire=0)
+
+        # Here comes the reported bug:
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder.A), ['C']) # <--
+
+        # 4a)
+        # BUT: removing 'View' is simply not enough!
+        # When using the workflow all is fine:
+        self.login()
+        self.workflow.doActionFor(self.folder.A.C, 'hide')
+
+        self.logout()
+        self.assertEqual(self._contentIds(self.folder.A), [])
+
+        # -> For folders you also have to remove 'Access contents information'
+        # -> Never click around in the ZMI security screens, use the workflow!
+
+
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
     suite.addTest(makeSuite(TestPloneFolder))
     suite.addTest(makeSuite(TestCheckIdAvailable))
+    suite.addTest(makeSuite(TestFolderListing))
     return suite
 
 if __name__ == '__main__':
