@@ -17,7 +17,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
 """Placeless Translation Service for providing I18n to file-based code.
 
-$Id: PlacelessTranslationService.py,v 1.37 2004/07/10 08:52:27 tiran Exp $
+$Id: PlacelessTranslationService.py,v 1.37.2.1 2004/11/25 22:23:35 longsleep Exp $
 """
 
 import sys, os, re, fnmatch
@@ -163,7 +163,7 @@ class PlacelessTranslationService(Folder):
     # -3 for alpha, -2 for beta, -1 for release candidate
     # for forked releases internal is always 99
     # use an internal of >99 to recreate the PTS at every startup (development mode)
-    _class_version = (1, -1, 16, 0)
+    _class_version = (1, 1, 2, 0)
     all_meta_types = ()
 
     security = ClassSecurityInfo()
